Quickstart — mosaik 2.0a1 documentation

# Quickstart

Mosaik runs on Linux, OS X and Windows. It requires Python 3.3 or newer. To install everything, you need the package manager Pip which is bundled with Python 3.4 and above.

We also strongly recommend you to install everything into a virtualenv.

Installing mosaik is very easy:

    $ pip install mosaik

There is also a demo scenario that you can try. You can get it from Bitbucket:

    $ hg clone https://bitbucket.org/mosaik/mosaik-demo
    $ cd mosaik-demo/
    $ pip install -r requirements
    $ python demo.py

Then open your browser and go to http://localhost:8000.